==> speech-analytic-testing_3.6.0_database.tar.gz: database/mssql/procedures/GetEvaluationPlanByInteractionId.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetEvaluationPlanByInteractionId] (
	@VCC VARCHAR(50) = NULL,
	@InteractionId VARCHAR(250) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

 	SELECT TOP 1
		EP.[ID]									'id',
		EP.[Modality]							'modality',
		EP.[DateFin]							'dateFin',
		EP.[CreatedDate]						'createdDate',
		EP.[CreatedByUserId]					'createdByUserId',
		EP.[LastModifiedDate]					'lastModifiedDate',
		EP.[LastModifiedByUserId]				'lastModifiedByUserId',
		EP.[Description]						'description',
		EP.[IdEvaluationFormat]					'idEvaluationFormat',
		EP.[EnvironmentId]						'environmentId',
		EP.[Enabled]							'enabled',
		EP.[Status]								'status',
        EP.[Evaluation_Mode]					'evaluation_mode',
        EP.[processId]    						'processId',
        EP.FilterByContent						'filterByContent',
        EP.EvaluatePercentage					'evaluatePercentage',
        EP.ProcessAndEvaluate    				'processAndEvaluate',
		IEP.[RelativePath]						'relativePath',
		IEP.[FileName]							'fileName'
	FROM EvaluationPlan EP (NOLOCK) 
	INNER JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
		ON IEP.[IdEvaluationPlan] = EP.[ID]
	WHERE EP.[Instance] = @VCC
		AND IEP.[IdInteraction] = @InteractionId
	GROUP BY EP.[ID], EP.[Modality], EP.[DateFin], EP.[CreatedDate], EP.[CreatedByUserId],
			 EP.[LastModifiedDate], EP.[LastModifiedByUserId], EP.[Description], EP.[IdEvaluationFormat], EP.[EnvironmentId], 
			 EP.[Enabled], EP.[Status], EP.[Evaluation_Mode], EP.[processId], EP.[FilterByContent], 
			 EP.[EvaluatePercentage], EP.[ProcessAndEvaluate], IEP.[RelativePath], IEP.[FileName]
	ORDER BY EP.[CreatedDate] DESC

 	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_5.2.11_database.tar.gz: database/mssql/procedures/GetEvaluationPlanByInteractionId.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetEvaluationPlanByInteractionId] (
	@VCC VARCHAR(50) = NULL,
	@InteractionId VARCHAR(250) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

 	SELECT TOP 1
		EP.[ID]									'id',
		EP.[Modality]							'modality',
		EP.[DateFin]							'dateFin',
		EP.[CreatedDate]						'createdDate',
		EP.[CreatedByUserId]					'createdByUserId',
		EP.[LastModifiedDate]					'lastModifiedDate',
		EP.[LastModifiedByUserId]				'lastModifiedByUserId',
		EP.[Description]						'description',
		EP.[IdEvaluationFormat]					'idEvaluationFormat',
		EP.[EnvironmentId]						'environmentId',
		EP.[Enabled]							'enabled',
		EP.[Status]								'status',
        EP.[Evaluation_Mode]					'evaluation_mode',
        EP.[processId]    						'processId',
        EP.FilterByContent						'filterByContent',
        EP.EvaluatePercentage					'evaluatePercentage',
        EP.ProcessAndEvaluate    				'processAndEvaluate',
		IEP.[RelativePath]						'relativePath',
		IEP.[FileName]							'fileName',	
		IEP.[RelativeFileName]					'relativeFileName'
	FROM EvaluationPlan EP (NOLOCK) 
	INNER JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
		ON IEP.[IdEvaluationPlan] = EP.[ID]
	WHERE EP.[Instance] = @VCC
		AND IEP.[IdInteraction] = @InteractionId
	GROUP BY EP.[ID], EP.[Modality], EP.[DateFin], EP.[CreatedDate], EP.[CreatedByUserId],
			 EP.[LastModifiedDate], EP.[LastModifiedByUserId], EP.[Description], EP.[IdEvaluationFormat], EP.[EnvironmentId], 
			 EP.[Enabled], EP.[Status], EP.[Evaluation_Mode], EP.[processId], EP.[FilterByContent], 
			 EP.[EvaluatePercentage], EP.[ProcessAndEvaluate], IEP.[RelativePath], IEP.[FileName], IEP.[RelativeFileName]
	ORDER BY EP.[CreatedDate] DESC

 	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
